@@ -279,6 +279,12 @@ return array(
 					'label' => $lng['menue']['phpsettings']['maintitle'],
 					'show_element' => (Settings::Get('system.mod_fcgid') == true || Settings::Get('phpfpm.enabled') == true)
 				),
+				array(
+					'url' => 'admin_phpsettings.php?page=fpmdaemons',
+					'label' => $lng['menue']['phpsettings']['fpmdaemons'],
+					'required_resources' => 'change_serversettings',
+					'show_element' => Settings::Get('phpfpm.enabled') == true
+				),
 				array(
 					'url' => 'admin_settings.php?page=phpinfo',
 					'label' => $lng['admin']['phpinfo'],
